% init
clear all, close all, clc

% load experimental data
[w, d] = load_data('samples/iPrOH.csv', true);

% convert data to sRGB space
RGB = spectrum2srgb(w, d);

fprintf('RGB = (%.0f, %.0f, %.0f)\n', 255 * RGB);

% create artificial image
height = 64;

img = create_spectral_image(w, d, height);

% plot spectrum
figure(1)
subplot(3,1,1:2);
plot(w, d, 'Color', 'black')
xlim([w(1), w(end)])
ylim([0, 1])
ylabel('Intensity (a.u.)')
grid minor
box on
drawnow

% draw colored box on top
box_width = 0.1 * (w(end) - w(1));
box_height = 0.2;

left = w(1) + 0.5 * box_width;
top = 0.95 - box_height;

rectangle('Position', [left, top, box_width, box_height], 'FaceColor', RGB);
drawnow

% plot spectral image
figure(1)
subplot(3,1,3)
imagesc(w, 1:height, img);
xlabel('Wavelength (nm)')
set(gca, 'TickDir', 'out');
set(gca, 'ytick', [])
drawnow

% update window size
pos = get(figure(1), 'Position');

set(figure(1), 'Position', [pos(1), pos(2), 640, 420])